==> kleandisk-2.0beta2.tar.gz: kleandisk-2.0beta2/kleandisk/kleandisk.h <==
/***************************************************************************
                          kleandisk.h  -  description
                             -------------------
    begin                : wo feb  7 09:47:42 CET 2001
    copyright            : (C) 2001 by Arjan Buursink
    email                : buursink@wanadoo.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KLEANDISK_H
#define KLEANDISK_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapp.h>
#include <kmainwindow.h>

#include "groupviewwidget.h"

/** Kleandisk is the base class of the project */
class Kleandisk : public KMainWindow
{
  Q_OBJECT 
public:
	/** construtor */
	Kleandisk();
	/** destructor */
	~Kleandisk();
private:
	GroupViewWidget * groupViewWidget;
	void resizeEvent(QResizeEvent*);
private slots:
	void slotUninstallINS();
	void slotUninstallRPM();
	void slotConfigure();
	void slotRestore();
	void slotClose();
};

#endif

void endInstall();

==> kleandisk-2.1beta2.tar.gz: kleandisk-2.1beta2/kleandisk/kleandisk.h <==
/***************************************************************************
                          kleandisk.h  -  description
                             -------------------
    begin                : wo feb  7 09:47:42 CET 2001
    copyright            : (C) 2001 by Arjan Buursink
    email                : buursink@wanadoo.nl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef KLEANDISK_H
#define KLEANDISK_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapp.h>
#include <kmainwindow.h>

#include "groupviewwidget.h"

#define CHECKWAIT if (cursor().shape() == 3) return
#define SETWAIT groupViewWidget() -> setCursor(waitCursor)
#define SETARROW groupViewWidget() -> setCursor(arrowCursor)


/** Kleandisk is the base class of the project */
class Kleandisk : public KMainWindow
{
  Q_OBJECT 
public:
	/** construtor */
	Kleandisk();
	/** destructor */
	~Kleandisk();
private:
	GroupViewWidget * groupViewWidget;
	void resizeEvent(QResizeEvent*);
private slots:
	void slotUninstallINS();
	void slotUninstallRPM();
	void slotConfigure();
	void slotRestore();
	void slotClose();
};

#endif

void endInstall();
